@@ -24,8 +24,8 @@ List get_mellin_QF(NumericVector lambdas,
 
 
   double lambda_min = Rcpp::min(lambdas);
-  double eps_mell = eps * lambda_min * 0.01;
-  double eps_trunc = eps * lambda_min;
+  double eps_mell = eps * 0.01;
+  double eps_trunc = eps;
   double eps_discr = eps * 0.1;
 
   NumericVector lambdas_scal = lambdas / lambda_min;
@@ -43,7 +43,7 @@ List get_mellin_QF(NumericVector lambdas,
                         eps_mell,
                         1.0);
   }
-  if(ak.size() == maxit_ak){// stop with error if the ak did not converged
+  if(ak.size() == maxit_ak){// stop with error if the ak did not converge
     stop("Computation of the a_k coefficients did not converged: consider to increase 'maxit_comp'");
   }
 
@@ -110,6 +110,7 @@ List get_mellin_QF(NumericVector lambdas,
         range_q_ref);
       range_q_ref = qQF_c(range_p, Mellin_new, eps_quant,
                               maxit_quant,sum(lambdas_scal));
+
       range_f_new = dQF_c(range_q_ref, Mellin_new);
       for(int k=0; k<2; k++) {
         range_f_new[k] *= 1.0 / lambda_min;
@@ -130,7 +131,7 @@ List get_mellin_QF(NumericVector lambdas,
         break; //stop if the error is lower that the threshold
       }
       if(i == maxit_delta - 1){// stop with error if maxit_delta is reached without the desired error
-        stop("Computation of the integration step 'delta' did not converged: consider to increase 'maxit_comp'");
+        stop("Computation of the integration step 'delta' did not converge: consider to increase 'maxit_comp'");
       }
       // new become reference
       range_F_ref = range_F_new;/// DA TOGLIERE
@@ -142,7 +143,8 @@ List get_mellin_QF(NumericVector lambdas,
       Mellin_ref = Mellin_new;
     }
     // definitive quantities
-    range_q_ref = qQF_c(range_p, Mellin_new, eps_quant,maxit_quant,sum(lambdas_scal));
+    range_q_ref = qQF_c(range_p, Mellin_ref, eps_quant,maxit_quant,sum(lambdas_scal));
+
     delta = delta * 2.0;
   }else{// increase delta
     for(int i=0; i<maxit_delta; i++){
@@ -180,6 +182,8 @@ List get_mellin_QF(NumericVector lambdas,
     }
   Mellin_ref["lambda_min"] = lambda_min;
   return List::create(
+    Named("range_F") = range_F_new,
+    Named("range_f") = range_f_new,
     Named("range_q") = range_q_ref,
     Named("Mellin") = Mellin_ref,
     Named("rho") = rho
